@@ -1,6 +1,6 @@
 #' @importFrom grDevices as.raster
 #' @export
-#' @title image chunk wrapper
+#' @title Image chunk wrapper
 #' @description The function lets add images within flextable
 #' objects with functions:
 #' - [compose()] and [as_paragraph()],
@@ -78,7 +78,7 @@ as_image <- function(src, width = NULL, height = NULL, unit = "in", guess_size =
 
 
 #' @export
-#' @title mini barplots chunk wrapper
+#' @title Mini barplots chunk wrapper
 #' @description This function is used to insert bars into
 #' flextable with functions:
 #' - [compose()] and [as_paragraph()],
@@ -151,7 +151,7 @@ minibar <- function(value, max = NULL, barcol = "#CCCCCC", bg = "transparent", w
 }
 
 #' @export
-#' @title mini linerange chunk wrapper
+#' @title Mini linerange chunk wrapper
 #' @description This function is used to insert lineranges into
 #' flextable with functions:
 #' - [compose()] and [as_paragraph()],
@@ -243,7 +243,7 @@ linerange <- function(value, min = NULL, max = NULL, rangecol = "#CCCCCC",
 }
 
 #' @export
-#' @title mini lollipop chart chunk wrapper
+#' @title Mini lollipop chart chunk wrapper
 #' @description This function is used to insert lollipop charts into
 #' flextable with functions:
 #' - [compose()] and [as_paragraph()],
@@ -367,7 +367,7 @@ lollipop <- function(value, min = NULL, max = NULL, rangecol = "#CCCCCC",
 
 
 #' @export
-#' @title mini plots chunk wrapper
+#' @title Mini plots chunk wrapper
 #' @description This function is used to insert mini plots into
 #' flextable with functions:
 #' - [compose()] and [as_paragraph()],
@@ -408,7 +408,7 @@ lollipop <- function(value, min = NULL, max = NULL, rangecol = "#CCCCCC",
 #' ft <- set_table_properties(ft, layout = "autofit", width = .6)
 #' ft <- set_header_labels(ft, box = "boxplot", density= "density")
 #' theme_vanilla(ft)
-#' @importFrom grDevices dev.off png
+#' @importFrom grDevices dev.off
 #' @importFrom graphics boxplot
 #' @importFrom stats density
 plot_chunk <- function(value, width = 1, height = .2,
@@ -435,8 +435,11 @@ plot_chunk <- function(value, width = 1, height = .2,
 
   files <- mapply(function(x, width, height, type){
     file <- tempfile(fileext = ".png")
-    png(filename = file, width = width, height = height,
-        units = "in", bg = "transparent", res = 300)
+    agg_png(
+      filename = file,
+      width = width, height = height,
+      res = 200, units = "in",
+      background = "transparent")
     par(mar = rep(0,4))
     parcall <- params
 
@@ -477,7 +480,7 @@ plot_chunk <- function(value, width = 1, height = .2,
 
 
 #' @export
-#' @title ggplots chunk wrapper
+#' @title 'ggplots' chunk wrapper
 #' @description This function is used to insert mini gg plots into
 #' flextable with functions:
 #' - [compose()] and [as_paragraph()],
@@ -532,8 +535,8 @@ gg_chunk <- function(value, width = 1, height = .2, unit = "in", res = 300) {
 
   files <- mapply(function(x, width, height){
     file <- tempfile(fileext = ".png")
-    png(filename = file, width = width, height = height,
-        units = "in", bg = "transparent", res = res)
+    agg_png(filename = file, width = width, height = height,
+        units = "in", background = "transparent", res = res)
       print(x)
     dev.off()
     file
@@ -599,8 +602,8 @@ grid_chunk <- function(value, width = 1, height = .2, unit = "in", res = 300) {
 
   files <- mapply(function(x, width, height){
     file <- tempfile(fileext = ".png")
-    png(filename = file, width = width, height = height,
-        units = "in", bg = "transparent", res = res)
+    agg_png(filename = file, width = width, height = height,
+        units = "in", background = "transparent", res = res)
     grid::grid.draw(x)
     dev.off()
     file
