@@ -5,10 +5,7 @@ gen_raw_html <- function(x,
                          manual_css = "") {
 
   align <- x$properties$align
-  shadow <- x$properties$opts_html$shadow
-
   # for ubiquity and other packages that dump old flextable
-  if(is.null(shadow)) shadow <- TRUE
   if(is.null(align)) align <- "center"
 
   fixed_layout <- x$properties$layout %in% "fixed"
@@ -70,7 +67,7 @@ gen_raw_html <- function(x,
     x$properties$opts_html$extra_css,
     manual_css_str,
     "</style>",
-    sprintf("<table class='%s'>", classname),
+    sprintf("<table data-quarto-disable-processing='true' class='%s'>", classname),
     caption,
     codes$html,
     "</table>"
@@ -96,43 +93,9 @@ gen_raw_html <- function(x,
   }
 
   html <- paste0("<div class=\"", tab_class, "\"", style_div, ">", html, "</div>")
-
-  if (shadow) {
-    uid <- UUIDgenerate(n = 2L)
-
-    tabwid_css <- paste(
-      c(
-        "<style>",
-        readLines(system.file(package = "flextable", "web_1.1.2", "tabwid.css"), encoding = "UTF-8"),
-        "</style>"
-      ),
-      collapse = "\n"
-    )
-
-    html <- paste0(
-      "<template id=\"", uid[1], "\">",
-      tabwid_css,
-      html,
-      "</template>",
-      "\n<div class=\"flextable-shadow-host\" id=\"", uid[2], "\"></div>",
-      to_shadow_dom(uid1 = uid[1], uid2 = uid[2])
-    )
-  }
   html
 }
 
-to_shadow_dom <- function(uid1, uid2) {
-  script_commands <- c(
-    "", "<script>",
-    paste0("var dest = document.getElementById(\"", uid2, "\");"),
-    paste0("var template = document.getElementById(\"", uid1, "\");"),
-    "var fantome = dest.attachShadow({mode: 'open'});",
-    "var templateContent = template.content;",
-    "fantome.appendChild(templateContent);",
-    "</script>", ""
-  )
-  paste(script_commands, collapse = "\n")
-}
 
 scrollbox <- function(height = NULL, add_css = "", ...) {
   str <- "overflow-x:auto;width:100%;"
@@ -263,55 +226,25 @@ htmlize <- function(x){
   x
 }
 
-#' @importFrom base64enc dataURI
+#' @importFrom officer image_to_base64
 img_as_html <- function(img_data, width, height){
-  str_raster <- mapply(function(img_raster, width, height ){
-
+  img_data <- str_raster <- mapply(function(img_raster, width, height ){
     if(inherits(img_raster, "raster")){
       outfile <- tempfile(fileext = ".png")
-      png(filename = outfile, units = "in", res = 300, bg = "transparent", width = width, height = height)
+      agg_png(filename = outfile, units = "in", res = 300, background = "transparent", width = width, height = height)
       op <- par(mar=rep(0, 4))
       plot(img_raster, interpolate = FALSE, asp=NA)
       par(op)
       dev.off()
       img_raster <- outfile
     }
-
-    if(is.character(img_raster)){
-
-      if( grepl("\\.png", ignore.case = TRUE, x = img_raster) ){
-        mime <- "image/png"
-      } else if( grepl("\\.gif", ignore.case = TRUE, x = img_raster) ){
-        mime <- "image/gif"
-      } else if( grepl("\\.jpg", ignore.case = TRUE, x = img_raster) ){
-        mime <- "image/jpeg"
-      } else if( grepl("\\.jpeg", ignore.case = TRUE, x = img_raster) ){
-        mime <- "image/jpeg"
-      } else if( grepl("\\.svg", ignore.case = TRUE, x = img_raster) ){
-        mime <- "image/svg+xml"
-      } else if( grepl("\\.tiff", ignore.case = TRUE, x = img_raster) ){
-        mime <- "image/tiff"
-      } else if( grepl("\\.webp", ignore.case = TRUE, x = img_raster) ){
-        mime <- "image/webp"
-      } else {
-        stop(sprintf("'flextable' does not support format of the file '%s'.", img_raster))
-      }
-      if(!file.exists(img_raster)){
-        stop(sprintf("file '%s' can not be found.",img_raster))
-      }
-      img_raster <- base64enc::dataURI(file = img_raster, mime = mime )
-
-    } else  {
-      stop("unknown image format")
-    }
-    sprintf("<img style=\"vertical-align:baseline;width:%.0fpx;height:%.0fpx;\" src=\"%s\" />", width*72, height*72, img_raster)
-  }, img_data, width, height, SIMPLIFY = FALSE, USE.NAMES = FALSE)
-  str_raster <- as.character(unlist(str_raster))
-  str_raster
+    img_raster
+  }, img_data, width, height,
+  SIMPLIFY = TRUE, USE.NAMES = FALSE)
+  base64_strings <- image_to_base64(img_data)
+  sprintf("<img style=\"vertical-align:baseline;width:%.0fpx;height:%.0fpx;\" src=\"%s\" />", width*72, height*72, base64_strings)
 }
 
-
-
 # css ----
 
 css_pt <- function(x, digits = 1){
@@ -439,11 +372,14 @@ cell_css_styles <- function(x, add_widths = TRUE){
 #' @examples
 #' if(require("htmltools"))
 #'   div(flextable_html_dependency())
+#' @keywords internal
 flextable_html_dependency <- function(){
   htmlDependency("tabwid",
-                 "1.1.2",
-                 src = system.file(package="flextable", "web_1.1.2"),
-                 stylesheet = "tabwid.css")
+                 "1.1.3",
+                 src = system.file(package="flextable", "web_1.1.3"),
+                 stylesheet = "tabwid.css",
+                 script = "tabwid.js"
+                 )
 
 }
 
